@@ -203,7 +203,9 @@ def showGraph(self,  QtGui):
     print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
     
     OffsetToLastFullHour=-1*(GraphStart_index-LastFullHour_index)/Xscale 
-    OffsetToLastFullHour=OffsetToLastFullHour-data.Derivation #Derivation takes 5 idnices, so visualisation is delayed!
+    OffsetToLastFullHour=OffsetToLastFullHour-data.Derivation/Xscale  #Derivation takes 5 idnices, so visualisation is delayed!
+
+    print "Last data is on:",  Index2Tuple(records.Index)
     
     #DRAW main scaling lines + text        
     paint.setPen(QtGui.QColor("white"))
