@@ -186,20 +186,30 @@ def InitMeasurement():
 
     PrintRecordData()
     
-    #go offline if requested
+    #set scale and sampling interval
     if(data.QuickMode==False):
         data.interval=data.Sampling_interval #normal
+        data.Xscale=1 #set to default zoom level
+    else:  
+        data.interval=10 #Fast mode for testing
+        data.Xscale=0 #set to max zoom level
+    
+    #change to offline mode and silent profile if requested
+    if(data.QuickMode==False):
         if(data.OfflineMode=="True"): #change to offline mode
             try:
                 cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
                 os.popen(cmd)
             except:
                 pass
-        data.Xscale=1 #set to default zoom level
-    else:  
-        data.interval=10 #Fast mode for testing
-        data.Xscale=0 #set to max zoom level
-    
+        if(data.SilentProfile=="True"): #change to offline mode
+            try:
+                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
+                os.popen(cmd)
+                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Silent Profile activated\""
+                os.popen(cmd)
+            except:
+                pass   
 
     data.run=2 #change to recording
     app.timer_GetData = QtCore.QTimer()
@@ -245,7 +255,7 @@ def StopMeasurement():
 
     data.run=0
 
-    
+    #change back to nromal mode and general profile if requested
     if(data.QuickMode==False): #normal mode
         if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
             try:
@@ -253,7 +263,14 @@ def StopMeasurement():
                 os.popen(cmd)
             except:
                 pass
-
+        if(data.SilentProfile=="True" and data.demo!=1): #change to offline mode
+            try:
+                cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
+                os.popen(cmd)                
+                cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"General Profile activated\""
+                os.popen(cmd)       
+            except:
+                pass
 
 
 
@@ -920,37 +937,51 @@ class frmViewWindow(QMainWindow):
         d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
         EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
         if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", EndTime_tuple)):
-            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) #on same day, only show date once
+            d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
         else:
             d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
         
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
-        diff_tuple=Seconds2Tuple(diff_sec)
-        diff=strftime("%H:%M:%S", EndTime_tuple)
-        if(diff_sec>86400): d="1 day, " #longer than 24h
-        else: d=""
+#        diff_tuple=Seconds2Tuple(diff_sec)
+#        diff=strftime("%H:%M:%S", diff_tuple)
+        diff=time.strftime("%X", time.gmtime(diff_sec))
+        
+        if(diff_sec>86400): diff="1 day, "+diff #longer than 24h
+#        else: d=""
         
         if(records.AlarmIsSet==True):
-            alarm="Alarm Time Window: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowStart_tuple)+" - "+ \
-            strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple)+"\n" +\
-            "Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"\n"
+            a0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowStart_tuple)
+            if(strftime("%d.%m.%Y", records.AlarmTimeWindowStart_tuple)==strftime("%d.%m.%Y", records.AlarmTimeWindowEnd_tuple)):
+                a1=strftime("%H:%M:%S", records.AlarmTimeWindowEnd_tuple) #on same day, only show date once
+            else:
+                a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple) 
+            alarm="Alarm Time Window: "+a0+" - "+a1 + ", "
+            if(records.AlarmTime_seconds!=-1): #alarm went off
+                alarm=alarm+"Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)
+                if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
+                    alarm=alarm+" at end of alarm time window\n"
+                else:
+                    alarm=alarm+" due strong movements\n"
+            else:
+                alarm=alarm+"Alarm never went off\n"
         else:
             alarm="Alarm: No alarm was set\n"
         
-        QtGui.QMessageBox.information(self, 'About this record', "File: "+str(data.logfilename+"\n") + \
-        "Folder: "+str(shortfolder) +"\n" + \
+        QtGui.QMessageBox.information(self, 'About this record', "File: "+str(shortfolder)+str(data.logfilename+"\n") + \
+#        "Folder: "+str(shortfolder) +"\n" + \
         "User: "+records.User +"\n" + \
-        "Start: "+d0 + "\n" + \
-        "End: "+d1 + "\n" + \
-        "Duration: "+diff + ", " + \
+#        "Start: "+d0 + "\n" + \
+#        "End: "+d1 + "\n" + \
+        "Time: "+d0+" - "+d1+" (Duration: "+ diff+"), " + \
+#        "Duration: "+diff + ", " + \
         "Total "+str(records.Index)+" entries\n" +\
         "Note: "+records.Note+"\n" +\
         alarm +\
+#        "Trigger level: "+str(records.Trigger) + "\n" + \
         "Condition of record: "+str(records.status)+"\n" + \
-        "Sampling interval: "+str(records.Sampling_interval) + ", " + \
-        "Sampling smoothing: "+str(records.Sample_smoothing) + ", " + \
-        "Value smoothing: "+str(records.Value_smoothing) + ", " + \
-        "Trigger level: "+str(records.Trigger) + "\n" + \
+#        "Sampling interval: "+str(records.Sampling_interval) + ", " + \
+#        "Sampling smoothing: "+str(records.Sample_smoothing) + ", " + \
+#        "Value smoothing: "+str(records.Value_smoothing) + ", " + \
         "Record version "+str(records.SWversion))
         
 
@@ -980,7 +1011,9 @@ class frmConfigWindow(QMainWindow):
 
     def UpdateScreen(self):
         if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
-        else: self.ui.cOfflineMode.setChecked(False)        
+        else: self.ui.cOfflineMode.setChecked(False)    
+        if(data.SilentProfile=="True"): self.ui.cSilentProfile.setChecked(True)
+        else: self.ui.cSilentProfile.setChecked(False)        
         self.ui.lblUserName.setText(data.user)
         self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
@@ -992,6 +1025,13 @@ class frmConfigWindow(QMainWindow):
         else: 
             data.OfflineMode="False"
         config.set('main', 'OfflineMode', str(data.OfflineMode))   
+        
+        if(self.ui.cSilentProfile.isChecked()==True):          
+                data.SilentProfile="True"
+        else: 
+            data.SilentProfile="False"
+        config.set('main', 'SilentProfile', str(data.SilentProfile))   
+        
         config.set('main', 'user', str(data.user.encode( "utf-8" )))      
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
         
